==> hgu95a_1.8.4.tar.gz: hgu95a/man/hgu95aPMID2PROBE.Rd <==
\name{hgu95aPMID2PROBE}
\alias{hgu95aPMID2PROBE}
\title{Map between PubMed Identifiers and Manufacturer Identifiers}
\description{
  hgu95aPMID2PROBE is an R environment that provides mappings between
  PubMed ids and manufacturer ids.
}
\details{
  Each PubMed id is mapped to a named vector of manufacturer ids. The
  name represents the PubMed id and the vector contains all manufacturer
  ids that are represented by that PubMed id. The length of the vector
  may be one or longer, depending on how many manufacturer ids are
  mapped to a given PubMed id.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed id. The pubmed function of
  annotate can also be used for the same purpose
  
  Mappings were based on data provided by:
  
  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue May 17 12:34:58 2005 
  
  Package built Tue May 17 12:43:04 2005
}

\examples{
    # Convert the environment to a list
    xx <- as.list(hgu95aPMID2PROBE)
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && require(annotate)){
            # Gets article information as XML files for a PubMed id
            xmls <- pubmed(names(xx)[1], disp = "data")
            # Views article information using a browser
            pubmed(names(xx)[1], disp = "browser")
        }
    }
}

\keyword{datasets}

==> hgu95a_1.10.0.tar.gz: hgu95a/man/hgu95aPMID2PROBE.Rd <==
\name{hgu95aPMID2PROBE}
\alias{hgu95aPMID2PROBE}
\title{Map between PubMed Identifiers and Manufacturer Identifiers}
\description{
  hgu95aPMID2PROBE is an R environment that provides mappings between
  PubMed ids and manufacturer ids.
}
\details{
  Each PubMed id is mapped to a named vector of manufacturer ids. The
  name represents the PubMed id and the vector contains all manufacturer
  ids that are represented by that PubMed id. The length of the vector
  may be one or longer, depending on how many manufacturer ids are
  mapped to a given PubMed id.

  Titles, abstracts, and possibly full texts of articles can be obtained
  from PubMed by providing a valid PubMed id. The pubmed function of
  annotate can also be used for the same purpose
  
  Mappings were based on data provided by:
  
  Entrez Gene:\url{http://gopher5/compbio/annotationSourceData/ftp.ncbi.nlm.nih.gov/gene/DATA/}. Built: Source data downloaded from Entrez Gene on Tue Oct  4 20:58:25 2005 
  
  Package built Tue Oct  4 21:14:11 2005
}

\examples{
    # Convert the environment to a list
    xx <- as.list(hgu95aPMID2PROBE)
    if(length(xx) > 0){
        # The probe ids for the first two elements of XX
        xx[1:2]
        # Get the first one
        xx[[1]]
        if(interactive() && require(annotate)){
            # Gets article information as XML files for a PubMed id
            xmls <- pubmed(names(xx)[1], disp = "data")
            # Views article information using a browser
            pubmed(names(xx)[1], disp = "browser")
        }
    }
}

\keyword{datasets}
